@@ -22,7 +22,7 @@ import re
 
 from distutils.dir_util  import copy_tree, remove_tree
 from pathlib             import Path
-from pony.orm            import *
+from pony.orm            import db_session, commit
 from tempfile            import TemporaryDirectory
 
 from ..config            import ( PACKAGE_SOURCES_PATH
@@ -42,12 +42,10 @@ from ..service.database  import ( Library
 
 from ..service.logging            import logger, clog
 from ..service.readLibFile        import readLibFile
-from ..service.writeAgdaDirFiles  import writeAgdaDirFiles
 from ..service.utils              import isURL, isGit, isIndexed, isLocal
 
 from .uninstall                   import uninstallLibrary
-
-# ----------------------------------------------------------------------------
+from .write_defaults              import write_defaults
 
 # ----------------------------------------------------------------------------
 # -- Install command variants
@@ -77,11 +75,11 @@ option = { 'branch'            : "master"
          , 'installing_depend' : False
          }
 
-
 # ----------------------------------------------------------------------------
+
 @db_session
 def installFromLocal():
-
+  
   global option
 
   if len(option["pathlib"]) == 0 or option["pathlib"] == ".":
@@ -98,26 +96,22 @@ def installFromLocal():
   agdaLibFiles = [ f for f in pwd.glob(option["name"] + LIB_SUFFIX) if f.is_file() ]
   agdaPkgFiles = [ f for f in pwd.glob(option["name"] + PKG_SUFFIX) if f.is_file() ]
 
-  if len(agdaLibFiles) == 0 and len(agdaPkgFiles) == 0:
+  if len(agdaLibFiles) + len(agdaPkgFiles) == 0:
     logger.error(" no libraries (" + LIB_SUFFIX + " or "\
                 + PKG_SUFFIX + ") files detected." )
     return None
-
-  libFile = Path("")
   
-  # -- TODO: offer the posibility to create a file agda-pkg!
+  libFile = Path("")
   if len(agdaPkgFiles) == 1:
     libFile = agdaPkgFiles[0]
   elif len(agdaLibFiles) == 1:
-    # -- TODO: offer the posibility to create a file agda-pkg!
     libFile = agdaLibFiles[0]
   else:
-    logger.error("None or many agda libraries files.")
-    logger.info("[!] Use --name to specify the library name.")
+    logger.error("[!] Use --name to specify the library name.")
     return None
 
   logger.info("Library file detected: " + libFile.name)
-
+  
   info = readLibFile(libFile)
 
   option["name"] = info.get("name", "")
@@ -125,10 +119,6 @@ def installFromLocal():
   if len(option["name"]) == 0:
     option["name"] = option["pathlib"].name
 
-  # logger.info("Library name: " + name)
-
-  # -- Let's attach a version number
-
   versionName = option["version"]
 
   if versionName == "" :
@@ -164,7 +154,7 @@ def installFromLocal():
   library = Library.get(name=option["name"])
 
   if library is None:
-    library = Library(name=option["name"])
+    library = Library( name=option["name"] )
 
   versionLibrary = LibraryVersion.get(library=library, name=versionName)
 
@@ -196,10 +186,10 @@ def installFromLocal():
   else:
     versionLibrary = LibraryVersion( library=library
                                    , name=versionName
-                                   , cached=True
+                                   , cached=True                  
                                    , editable=option["editable"]
                                    )
-
+    
   if option["editable"]:
     versionLibrary.origin   = pwd.as_posix()
     versionLibrary.editable = True
@@ -267,7 +257,7 @@ def installFromLocal():
         else:
           logger.warning(depend + " is not in the index")
     
-    versionLibrary.install(not(option["no_defaults"]))
+    versionLibrary.install( not(option["no_defaults"]) )
 
     commit()
     return versionLibrary
@@ -299,8 +289,8 @@ def installFromGit():
 
   with TemporaryDirectory() as tmpdir:
 
-    print("Using temporal directory:", tmpdir)
     try:
+      click.echo("Using temporary directory: {}".format(tmpdir))
       
       if Path(tmpdir).exists():
         remove_tree(tmpdir)
@@ -335,14 +325,12 @@ def installFromGit():
         size_length = response.headers.get('content-length')
         size = 0
         if size_length is None:
-          for block in response.iter_content(1024):
+          for _ in response.iter_content(1024):
               size += 1024
         else:
           size = size_length
         size = int(size)
 
-      # --
-
       logger.info("Downloading " + option["url"]  \
             + " (%s)" % str(humanize.naturalsize(size, binary=True)))
       
@@ -365,7 +353,7 @@ def installFromGit():
 
             bar.update(self.total)
 
-        click.echo("branch: " + option["branch"])
+        click.echo("Git branch: " + option["branch"])
 
         REPO = git.Repo.clone_from( option["url"]
                                   , tmpdir
@@ -396,7 +384,9 @@ def installFromGit():
       libVersion.library.url = option["url"]
       libVersion.library.default = not(option["no_defaults"])
 
-      if option["version"] != "": libVersion.sha = REPO.head.commit.hexsha
+      if option["version"] != "": 
+        libVersion.sha = REPO.head.commit.hexsha
+        
       commit()
       return libVersion
 
@@ -572,7 +562,6 @@ def install( ctx, libnames, src, version, no_defaults
       logger.error(" installation failed.")
       return
 
-
   if len(option["libnames"]) > 1 and option["version"] != "":
     return logger.error("--version option only works for one library.\n\
       Please consider to use nameLibrary@versionNumber.")
@@ -607,8 +596,6 @@ def install( ctx, libnames, src, version, no_defaults
 
     vLibrary = None
 
-    # click.echo(option)
-
     try:  
 
       if option["local"]:
@@ -636,4 +623,4 @@ def install( ctx, libnames, src, version, no_defaults
     else:
       logger.info("Unsuccessfully installation ({}).".format(option["libname"]))
 
-  writeAgdaDirFiles()
+  ctx.invoke(write_defaults, yes = yes)
